@@ -7,6 +7,7 @@ EXTENSIONS = {
     'apinotes': {'text', 'apinotes'},
     'asar': {'binary', 'asar'},
     'avif': {'binary', 'image', 'avif'},
+    'avsc': {'text', 'avro-schema'},
     'bash': {'text', 'shell', 'bash'},
     'bat': {'text', 'batch'},
     'bats': {'text', 'shell', 'bash', 'bats'},
@@ -150,6 +151,7 @@ EXTENSIONS = {
     'md': {'text', 'markdown'},
     'mdx': {'text', 'mdx'},
     'meson': {'text', 'meson'},
+    'metal': {'text', 'metal'},
     'mib': {'text', 'mib'},
     'mjs': {'text', 'javascript'},
     'mk': {'text', 'makefile'},
@@ -196,6 +198,7 @@ EXTENSIONS = {
     'py': {'text', 'python'},
     'pyi': {'text', 'pyi'},
     'pyproj': {'text', 'xml', 'pyproj'},
+    'pyt': {'text', 'python'},
     'pyx': {'text', 'cython'},
     'pyz': {'binary', 'pyz'},
     'pyzw': {'binary', 'pyz'},
@@ -270,6 +273,7 @@ EXTENSIONS = {
     'wsgi': {'text', 'wsgi', 'python'},
     'xhtml': {'text', 'xml', 'html', 'xhtml'},
     'xacro': {'text', 'xml', 'urdf', 'xacro'},
+    'xctestplan': {'text', 'json'},
     'xml': {'text', 'xml'},
     'xq': {'text', 'xquery'},
     'xql': {'text', 'xquery'},
@@ -328,6 +332,7 @@ NAMES = {
     '.prettierignore': {'text', 'gitignore', 'prettierignore'},
     '.pypirc': EXTENSIONS['ini'] | {'pypirc'},
     '.rstcheck.cfg': EXTENSIONS['ini'],
+    '.salt-lint': EXTENSIONS['yaml'] | {'salt-lint'},
     '.yamllint': EXTENSIONS['yaml'] | {'yamllint'},
     '.zlogin': EXTENSIONS['zsh'],
     '.zlogout': EXTENSIONS['zsh'],
@@ -336,6 +341,8 @@ NAMES = {
     '.zshenv': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
     'BUILD': EXTENSIONS['bzl'],
+    'Cargo.toml': EXTENSIONS['toml'] | {'cargo'},
+    'Cargo.lock': EXTENSIONS['toml'] | {'cargo-lock'},
     'CMakeLists.txt': EXTENSIONS['cmake'],
     'CHANGELOG': EXTENSIONS['txt'],
     'config.ru': EXTENSIONS['rb'],
@@ -371,6 +378,7 @@ NAMES = {
     'setup.cfg': EXTENSIONS['ini'],
     'sys.config': EXTENSIONS['erl'],
     'sys.config.src': EXTENSIONS['erl'],
+    'Vagrantfile': EXTENSIONS['rb'],
     'WORKSPACE': EXTENSIONS['bzl'],
     'wscript': EXTENSIONS['py'],
 }
